#ifndef _KYSEC_XML_H
#define _KYSEC_XML_H

#include <limits.h>
#define KYSEC_XML_PATH "/etc/kysec/xml/kysec.xml"

enum network_op_type {
	OP_UNKNOWN = 0,
	OP_ALLOW = 1,
	OP_DENY,
	OP_AUTH
};

enum netctl_server_type {
	SERV_UNKNOWN = 0,
	SERV_SYSTEM,
	SERV_USER,
	SERV_NETWORK
};

#define XML_HASH_SIZE 64
struct kysec_xml {
	char path[PATH_MAX];
	char hash[XML_HASH_SIZE + 1];
	int type;
	char name[NAME_MAX + 1];
	char ico[PATH_MAX];
	int server_type;
};

struct kysec_xml_kernel {
	char path[PATH_MAX];
	char hash[XML_HASH_SIZE + 1];
	int type;
};

#ifdef __cplusplus
extern "C" {
#endif

/* kysec.xml文件存放的是应用网络管控的信息 */

/* 添加一个节点到xml文件
 * @path: 程序路径
 * @type: 操作类型，enum network_op_type
 * @name: 服务名字
 * @ico: 服务的图标路径
 * @server_type: 服务类型，enum netctl_server_type
 * 返回值: 0:成功，1:包含该@path的节点已经存在，-1:出错
 */
int kysec_xml_add_node(uid_t uid, char *path, int type,
		char *name, char *ico, int server_type);

/* 从xml文件中删除一个节点
 * @path: 程序路径
 * 返回值: 0:成功，-1:出错
 */
int kysec_xml_remove_node(uid_t uid, char *path);

/* 更新xml文件的某一个节点
 * @path: 程序路径
 * @type: 操作类型，enum network_op_type，
 *        若type != OP_UNKNOWN则更新节点里的type值
 * @name: 服务名字，
 *        若name != NULL则更新节点里的name值
 * @ico: 服务的图标路径，
 *       若ico != NULL则更新节点里的ico值
 * @server_type: 服务类型，enum netctl_server_type，
 *       若server_type != SERV_UNKNOWN则更新节点中的server_type值
 *
 * 返回值: 0:成功，-1:失败
 */
int kysec_xml_update_node(uid_t uid, char *path, int type,
		char *name, char *ico, int server_type);

/* 获取xml文件中所有节点数据
 * 返回值: kysec_xml_kernel指针数组，大小为@count
 */
struct kysec_xml_kernel *kysec_xml_read_all_data(int *count);
/* 获取指定用户uid在xml文件中的所有节点数据 */
struct kysec_xml *kysec_xml_read_all_data_with_uid(uid_t uid, int *count);
/* 获取指定用户指定程序对应的信息 */
struct kysec_xml *kysec_xml_read_node_with_uid(uid_t uid, char *path);


#ifdef __cplusplus
}
#endif

#endif
